@@ -1,5 +1,6 @@
 import os
 import unittest
+import warnings
 
 from unittest.mock import ANY
 
@@ -474,7 +475,6 @@ class TestSliceGroup(unittest.TestCase):
         new_zone = self.slice.extract()
         self.assertIsInstance(new_zone, tp.data.zone.Zone)
         self.assertEqual(self.dataset.num_zones, nzones + 1)
-
         nzones = self.dataset.num_zones
         new_zones = self.slice.extract(
             mode=ExtractMode.OneZonePerConnectedRegion,
@@ -489,6 +489,78 @@ class TestSliceGroup(unittest.TestCase):
             with self.assertRaises((TecplotSystemError, TecplotLogicError)):
                 self.slice.extract()
 
+    def test_extract_none(self):
+        self.slice.show_start_and_end_slices=False
+        self.slice.show_primary_slice=False
+        nzones = self.dataset.num_zones
+        with warnings.catch_warnings(record=True) as w:
+            warnings.simplefilter("always", category=Warning)
+            new_zones = self.slice.extract(
+                mode=ExtractMode.SingleZone,
+                transient_mode=TransientOperationMode.SingleSolutionTime)
+            self.assertEqual(len(w), 1)
+
+        new_zones = list(new_zones)
+        self.assertEqual(self.dataset.num_zones, nzones + len(new_zones))
+        self.assertEqual(len(new_zones), 0)
+        with patch_tecutil('ExtractSlicesX', return_value=False):
+            with self.assertRaises((TecplotSystemError, TecplotLogicError)):
+                self.slice.extract()
+
+    def test_extract_show_start_end(self):
+        self.slice.show_start_and_end_slices=True
+        self.slice.show_primary_slice=False
+        nzones = self.dataset.num_zones
+        with warnings.catch_warnings(record=True) as w:
+            warnings.simplefilter("always", category=Warning)
+            new_zones = self.slice.extract(
+                mode=ExtractMode.SingleZone,
+                transient_mode=TransientOperationMode.SingleSolutionTime)
+            self.assertEqual(len(w), 1)
+
+        new_zones = list(new_zones)
+        self.assertEqual(self.dataset.num_zones, nzones + len(new_zones))
+        self.assertIsInstance(new_zones[0], tp.data.zone.Zone)
+        with patch_tecutil('ExtractSlicesX', return_value=False):
+            with self.assertRaises((TecplotSystemError, TecplotLogicError)):
+                self.slice.extract()
+
+    def test_extract_show_primary(self):
+        # The only instance in which a single zone is returned.
+        self.slice.show_start_and_end_slices=False
+        self.slice.show_primary_slice=True
+        nzones = self.dataset.num_zones
+        with warnings.catch_warnings(record=True) as w:
+            warnings.simplefilter("always", category=Warning)
+            new_zone = self.slice.extract(
+                mode=ExtractMode.SingleZone,
+                transient_mode=TransientOperationMode.SingleSolutionTime)
+            self.assertEqual(len(w), 1)
+            
+        self.assertEqual(self.dataset.num_zones, nzones + 1)
+        self.assertIsInstance(new_zone, tp.data.zone.Zone)
+        with patch_tecutil('ExtractSlicesX', return_value=False):
+            with self.assertRaises((TecplotSystemError, TecplotLogicError)):
+                self.slice.extract()
+
+    def test_extract_show_primary_and_start_end(self):
+        self.slice.show_start_and_end_slices=True
+        self.slice.show_primary_slice=True
+        nzones = self.dataset.num_zones
+        with warnings.catch_warnings(record=True) as w:
+            warnings.simplefilter("always", category=Warning)
+            new_zones = self.slice.extract(
+                mode=ExtractMode.SingleZone,
+                transient_mode=TransientOperationMode.SingleSolutionTime)
+            self.assertEqual(len(w), 1)
+
+        new_zones = list(new_zones)
+        self.assertEqual(self.dataset.num_zones, nzones + len(new_zones))
+        self.assertIsInstance(new_zones[0], tp.data.zone.Zone)
+        with patch_tecutil('ExtractSlicesX', return_value=False):
+            with self.assertRaises((TecplotSystemError, TecplotLogicError)):
+                self.slice.extract()
+
     def test_extract_transient(self):
         self.dataset.zone(0).strand = 1
         self.dataset.zone(0).solution_time = 1.0
@@ -501,7 +573,25 @@ class TestSliceGroup(unittest.TestCase):
             transient_mode=TransientOperationMode.AllSolutionTimes)
         z = list(z)
         self.assertGreater(len(z), 1)
-
+    
+    def test_extract_single_transient(self):
+        self.dataset.zone(0).strand = 1
+        self.dataset.zone(0).solution_time = 1.0
+        self.dataset.zone(1).strand = 1
+        self.dataset.zone(1).solution_time = 2.0
+        self.plot.active_fieldmap_indices = [0, 1]
+        
+        self.plot.solution_time = 1.0
+        z = self.slice.extract(mode=ExtractMode.SingleZone,
+            transient_mode=TransientOperationMode.SingleSolutionTime)
+        z = list(z)
+        self.assertIsInstance(z[0], tp.data.zone.Zone)
+        self.plot.solution_time = 2.0
+        z = self.slice.extract(mode=ExtractMode.SingleZone,
+            transient_mode=TransientOperationMode.SingleSolutionTime)
+        z = list(z)
+        self.assertIsInstance(z[0], tp.data.zone.Zone)
+        
     def test_eq(self):
         self.assertTrue(self.slice == self.plot.slice(0))
         self.assertTrue(self.slice != self.plot.slice(1))
